@@ -3,7 +3,7 @@ import urllib
 
 def check_samples():
     url = 'http://github.com/yomguy/timeside-samples/raw/master/samples/'
-    samples = ['guitar.wav', 'sweep.wav', 'sweep.flac', 'sweep.ogg', 'sweep.mp3', 'sweep_source.wav']
+    samples = ['guitar.wav', 'sweep.wav', 'sweep_mono.wav', 'sweep_32000.wav', 'sweep.flac', 'sweep.ogg', 'sweep.mp3', 'sweep_source.wav']
     path = os.path.normpath(os.path.dirname(__file__))
     dir = path + os.sep + 'samples'
 
